@@ -1,12 +1,13 @@
 from importlib import resources
 import json
 from typing import List
+import base64
 
 
 class Node:
-    def __init__(self, name: str, tooltip: str = None, color: str = None, level: int = None, radius: int = 15):
+    def __init__(self, name: str, tooltip: str = None, color: str = None, level: int = None, radius: int = 8):
         self.name = name
-        self.tooltip = tooltip
+        self.tooltip = tooltip or name
         self.color = color
         self.level = level
         self.radius = radius
@@ -23,15 +24,19 @@ class Link:
 class ForceDirectedGraph:
 
     def __init__(self, width: int = 800, height: int = 600, x_levels: int = -1,
-                 collision_radius: int = 15,
-                 show_node_names: bool = True):
+                 collision_radius: int = 8,
+                 show_node_names: bool = False,
+                 arrow_radius: int = 8):
         self._html = resources.read_text("py3js", "force.html")
         self._html = (self._html
                       .replace("$width", str(width))
                       .replace("$height", str(height))
                       .replace("$x_levels", str(x_levels))
                       .replace("$collision_radius", str(collision_radius))
-                      .replace("$showNodeNames", "true" if show_node_names else "false"))
+                      .replace("$showNodeNames", "true" if show_node_names else "false")
+                      .replace("$arrowRadius", str(arrow_radius)))
+        self._width = width
+        self._height = height
 
         self._nodes: List[Node] = []
         self._links: List[Link] = []
@@ -69,7 +74,12 @@ class ForceDirectedGraph:
         return r
 
     def _repr_html_(self):
-        return self._render_data()
+        data = self._render_data()
+        b64data = base64.b64encode(data.encode("utf-8")).decode("utf-8")
+        url = f"data:text/html;charset=utf-8;base64,{b64data}"
+        return f"<iframe src=\"{url}\" width=\"{self._width}\" height=\"{self._height}\" scrolling=\"no\" style=\"border:none !important;\"></iframe>"
+
+
 
     def save(self, path: str):
         with open(path, "w") as writer:
